@@ -10,7 +10,7 @@ class SignDatasetConfig(tfds.core.BuilderConfig):
     def __init__(
         self,
         include_video: bool = True,
-        process_video: bool = True,
+        process_video: bool = None,
         include_pose: Optional[str] = None,
         fps: Optional[float] = None,
         resolution: Optional[Tuple[int, int]] = None,
@@ -30,7 +30,7 @@ class SignDatasetConfig(tfds.core.BuilderConfig):
         """
         super(SignDatasetConfig, self).__init__(**kwargs)
         self.include_video = include_video
-        self.process_video = process_video
+        self.process_video = process_video if process_video is not None else include_video
         self.include_pose = include_pose.lower() if include_pose is not None else None
 
         self.fps = fps
